@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ttl-mode" "0.2.1"
+(define-package "ttl-mode" "20260210.1513"
   "Mode for Turtle (and Notation 3)."
   ()
   :url "https://github.com/emacsattic/ttl-mode"
